powered by
Create an SQL query to opendotas API and extracts a list of games from the public_matches table. This is only a sample of matches, not all are included here. Returns a vector of match ID's ready for use in the get_games() function.
get_game_list(num_matches, from_time, to_time, min_mmr = 1, min_duration = 1200, num_open_profile = 0)
Number of matches you want to extract
Earliest time of match in YMD text format.
Latest start time of the match in YMD text format.
Minimum average MMR of the match (defaulted to 1)
Minium match duration in seconds, defaulted to 1200 (20 minutes)
Minium number of open profiles in the game. Higher number here gives higher percentage of games that are actually parsed.
Returns data frame of results fulfilling the parameters input.
# NOT RUN { match_ids <- get_game_list(num_matches = 100, from_time = "20170101" , to_time = "20170423", min_mmr = 4000) # }
Run the code above in your browser using DataLab