how long to wait (in seconds) between each API call, default is 1 sec (opendota
asks you not to send more than 1 call per second)
output
Defaulted to "all", which will extract entire JSON, if not all, it should have the
path to an R file that will be sourced and create some output, not the R file must also
output to output_list()
verbose
Give live information on status of parsing, if FALSE no text is output to console.
Value
Returns a list of objects, if output == "all" it's a list of JSON outputs.